You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hive.apache.org by sz...@apache.org on 2021/08/04 14:40:50 UTC

[hive] branch master updated: HIVE-25420: Ignore time type column in Iceberg testing for vectorized runs (Adam Szita, reviewed by Peter Vary)

This is an automated email from the ASF dual-hosted git repository.

szita pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/hive.git


The following commit(s) were added to refs/heads/master by this push:
     new 31fb211  HIVE-25420: Ignore time type column in Iceberg testing for vectorized runs (Adam Szita, reviewed by Peter Vary)
31fb211 is described below

commit 31fb2111f8e9b109553de327e38de5c8b339b3e0
Author: Adam Szita <40...@users.noreply.github.com>
AuthorDate: Wed Aug 4 16:40:31 2021 +0200

    HIVE-25420: Ignore time type column in Iceberg testing for vectorized runs (Adam Szita, reviewed by Peter Vary)
---
 .../iceberg/mr/hive/TestHiveIcebergStorageHandlerWithEngine.java  | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/iceberg/iceberg-handler/src/test/java/org/apache/iceberg/mr/hive/TestHiveIcebergStorageHandlerWithEngine.java b/iceberg/iceberg-handler/src/test/java/org/apache/iceberg/mr/hive/TestHiveIcebergStorageHandlerWithEngine.java
index e056d64..6b1653f 100644
--- a/iceberg/iceberg-handler/src/test/java/org/apache/iceberg/mr/hive/TestHiveIcebergStorageHandlerWithEngine.java
+++ b/iceberg/iceberg-handler/src/test/java/org/apache/iceberg/mr/hive/TestHiveIcebergStorageHandlerWithEngine.java
@@ -421,8 +421,8 @@ public class TestHiveIcebergStorageHandlerWithEngine {
   public void testJoinTablesSupportedTypes() throws IOException {
     for (int i = 0; i < SUPPORTED_TYPES.size(); i++) {
       Type type = SUPPORTED_TYPES.get(i);
-      if (type == Types.TimestampType.withZone() && isVectorized) {
-        // ORC/TIMESTAMP_INSTANT is not a supported vectorized type for Hive
+      if ((type == Types.TimestampType.withZone() || type == Types.TimeType.get()) && isVectorized) {
+        // ORC/TIMESTAMP_INSTANT and time are not supported vectorized types for Hive
         continue;
       }
       // TODO: remove this filter when issue #1881 is resolved
@@ -448,8 +448,8 @@ public class TestHiveIcebergStorageHandlerWithEngine {
   public void testSelectDistinctFromTable() throws IOException {
     for (int i = 0; i < SUPPORTED_TYPES.size(); i++) {
       Type type = SUPPORTED_TYPES.get(i);
-      if (type == Types.TimestampType.withZone() && isVectorized) {
-        // ORC/TIMESTAMP_INSTANT is not a supported vectorized type for Hive
+      if ((type == Types.TimestampType.withZone() || type == Types.TimeType.get()) && isVectorized) {
+        // ORC/TIMESTAMP_INSTANT and time are not supported vectorized types for Hive
         continue;
       }
       // TODO: remove this filter when issue #1881 is resolved